@@ -252,6 +252,12 @@ namespace anyks {
 			 * @return      результат расчёта
 			 */
 			const ppl_t perplexity(const wstring & text) const noexcept;
+			/**
+			 * perplexity Метод расчёта перплексии текста
+			 * @param  words список слов для расчёта
+			 * @return       результат расчёта
+			 */
+			const ppl_t perplexity(const vector <wstring> & words) const noexcept;
 			/**
 			 * perplexity Метод расчёта перплексии
 			 * @param  seq список последовательностей
@@ -399,6 +405,11 @@ namespace anyks {
 			 * @param buffer буфер с бинарными данными
 			 */
 			virtual void setBin(const vector <char> & buffer) const noexcept;
+			/**
+			 * setBin2 Метод установки бинарных данных в словарь
+			 * @param buffer буфер с бинарными данными
+			 */
+			virtual void setBin2(const vector <char> & buffer) const noexcept;
 			/**
 			 * getBin Метод извлечения данных arpa в бинарном виде
 			 * @param callback функция обратного вызова
@@ -779,6 +790,12 @@ namespace anyks {
 			 * @return    количество найденных n-грамм
 			 */
 			const size_t grams(const vector <size_t> & seq) const noexcept;
+			/**
+			 * grams Метод проверки количества найденных n-грамм
+			 * @param words список слов для расчёта
+			 * @return      количество найденных n-грамм
+			 */
+			const size_t grams(const vector <wstring> & words) const noexcept;
 		public:
 			/**
 			 * bigrams Метод проверки количества найденных в тексте биграмм
@@ -792,6 +809,12 @@ namespace anyks {
 			 * @return    количество найденных биграмм
 			 */
 			const size_t bigrams(const vector <size_t> & seq) const noexcept;
+			/**
+			 * bigrams Метод проверки количества найденных биграмм
+			 * @param words список слов для расчёта
+			 * @return      количество найденных биграмм
+			 */
+			const size_t bigrams(const vector <wstring> & words) const noexcept;
 		public:
 			/**
 			 * trigrams Метод проверки количества найденных в тексте триграмм
@@ -805,6 +828,12 @@ namespace anyks {
 			 * @return    количество найденных триграмм
 			 */
 			const size_t trigrams(const vector <size_t> & seq) const noexcept;
+			/**
+			 * trigrams Метод проверки количества найденных последовательных триграмм
+			 * @param words список слов для расчёта
+			 * @return      количество найденных триграмм
+			 */
+			const size_t trigrams(const vector <wstring> & words) const noexcept;
 		public:
 			/**
 			 * Alm Конструктор
@@ -934,6 +963,11 @@ namespace anyks {
 			 * @param buffer буфер с бинарными данными
 			 */
 			virtual void setBin(const vector <char> & buffer) const noexcept;
+			/**
+			 * setBin2 Метод установки бинарных данных в словарь
+			 * @param buffer буфер с бинарными данными
+			 */
+			virtual void setBin2(const vector <char> & buffer) const noexcept;
 			/**
 			 * getBin Метод извлечения данных arpa в бинарном виде
 			 * @param callback функция обратного вызова
